package com.zhyc.module.produce.breed.mapper;

import java.util.List;
import com.zhyc.module.produce.breed.domain.ScBreedPlan;
import org.apache.ibatis.annotations.Mapper;

/**
 * 配种计划Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-16
 */
@Mapper
public interface ScBreedPlanMapper 
{
    /**
     * 查询配种计划
     * 
     * @param id 配种计划主键
     * @return 配种计划
     */
    public ScBreedPlan selectScBreedPlanById(Long id);

    /**
     * 查询配种计划列表
     * 
     * @param scBreedPlan 配种计划
     * @return 配种计划集合
     */
    public List<ScBreedPlan> selectScBreedPlanList(ScBreedPlan scBreedPlan);

    /**
     * 新增配种计划
     * 
     * @param scBreedPlan 配种计划
     * @return 结果
     */
    public int insertScBreedPlan(ScBreedPlan scBreedPlan);

    /**
     * 修改配种计划
     * 
     * @param scBreedPlan 配种计划
     * @return 结果
     */
    public int updateScBreedPlan(ScBreedPlan scBreedPlan);

    /**
     * 删除配种计划
     * 
     * @param id 配种计划主键
     * @return 结果
     */
    public int deleteScBreedPlanById(Long id);

    /**
     * 批量删除配种计划
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteScBreedPlanByIds(Long[] ids);
}
